@@ -1,35 +1,11 @@
+package App::ClusterSSH::Base;
+
 use warnings;
 use strict;
-
-package App::ClusterSSH::Base;
-$App::ClusterSSH::Base::VERSION = '4.18_06'; # TRIAL
-$App::ClusterSSH::Base::VERSION = '4.1806';
-# ABSTRACT: App::ClusterSSH::Base - Base object provding utility functions
-
-=head1 SYNOPSIS
-
-    use base qw/ App::ClusterSSH::Base /;
-
-    # in object new method
-    sub new {
-        ( $class, $arg_ref ) = @_;
-        my $self = $class->SUPER::new($arg_ref);
-        return $self;
-    }
-
-=head1 DESCRIPTION
-
-Base object to provide some utility functions on objects - should not be 
-used directly
-
-=cut
-
 use Carp;
 use App::ClusterSSH::L10N;
 
-use Module::Load;
-
-use Exception::Class 1.31 (
+use Exception::Class (
     'App::ClusterSSH::Exception',
     'App::ClusterSSH::Exception::Config' => {
         fields => 'unknown_config',
@@ -40,6 +16,10 @@ use Exception::Class 1.31 (
     'App::ClusterSSH::Exception::Getopt',
 );
 
+# Don't use SVN revision as it can cause problems
+use version;
+our $VERSION = version->new('0.02');
+
 my $debug_level = $ENV{CLUSTERSSH_DEBUG} || 0;
 our $language = 'en';
 our $language_handle;
@@ -162,21 +142,9 @@ sub config {
         );
     }
 
-    return $self->{parent}->{config}
-        if $self->{parent}
-        && ref $self->{parent} eq "HASH"
-        && $self->{parent}->{config};
-
     return $app_configuration;
 }
 
-sub options {
-    my ($self) = @_;
-    return $self->{parent}->{options}
-        if $self->{parent} && $self->{parent}->{options};
-    return;
-}
-
 sub set_config {
     my ( $self, $config ) = @_;
 
@@ -302,33 +270,29 @@ sub parent {
     return $self->{parent};
 }
 
-sub sort {
-    my $self = shift;
+1;
 
-    # if the user has asked for natural sorting we need to include an extra
-    # module
-    my $config = $self->config();
+=pod
 
-    # Make sure the configuration object has been set correctly before
-    # referencing anything
-    if ( ref $config eq "HASH" && $config->{'use_natural_sort'} ) {
-        eval { Module::Load::load('Sort::Naturally'); };
-        if ($@) {
-            warn(
-                "natural sorting requested but unable to load Sort::Naturally: $@\n"
-            );
-        }
-        else {
-            my $sort = sub { Sort::Naturally::nsort(@_) };
-            return $sort;
-        }
+=head1 NAME
+
+App::ClusterSSH::Base - Base object provding utility functions
+
+=head1 SYNOPSIS
+
+    use base qw/ App::ClusterSSH::Base /;
+
+    # in object new method
+    sub new {
+        ( $class, $arg_ref ) = @_;
+        my $self = $class->SUPER::new($arg_ref);
+        return $self;
     }
 
-    my $sort = sub { sort @_ };
-    return $sort;
-}
+=head1 DESCRIPTION
 
-1;
+Base object to provide some utility functions on objects - should not be 
+used directly
 
 =head1 METHODS
 
@@ -374,15 +338,11 @@ a wrapper to maketext in Locale::Maketext
 
 Output text on STDOUT.
 
-=item $obj->parent;
+=item $ovj->parent;
 
-Returned the object that is the parent of this one, if it was set when the 
+Reutrned the object that is the parent of this one, if it was set when the 
 object was created
 
-=item %obj->options;
-
-Accessor to configured options, if it is set up by this point
-
 =item $obj->exit;
 
 Stub to allow program to exit neatly from wherever in the code
@@ -396,14 +356,27 @@ hasnt been called
 
 Set the config to the given value - croaks if has already been called
 
-=item $sort = $obj->sort
-
-Code reference used to sort lists; if configured (and installed) use
-Sort;:Naturally, else use perl sort
-
 =item %results = $obj->load_file( filename => '/path/to/file', type => '(cluster|config}' )
 
 Load in the specified file and return a hash, parsing the file depending on
 wther it is a config file (key = value) or cluster file (key value)
 
 =back
+
+=head1 AUTHOR
+
+Duncan Ferguson, C<< <duncan_j_ferguson at yahoo.co.uk> >>
+
+=head1 LICENSE AND COPYRIGHT
+
+Copyright 1999-2016 Duncan Ferguson.
+
+This program is free software; you can redistribute it and/or modify it
+under the terms of either: the GNU General Public License as published
+by the Free Software Foundation; or the Artistic License.
+
+See http://dev.perl.org/licenses/ for more information.
+
+=cut
+
+1;
